# Changelog

## [stormi-v0.2.9](https://github.com/pinellolab/stormi/compare/stormi-v0.2.8...stormi-v0.2.9) (2025-05-16)

### Bug Fixes

* **preprocessing:** add batching and new motifs ([691e125](https://github.com/pinellolab/stormi/commit/691e125c29fe0b66be70383ace673611bd507151))
* **preprocessing:** fix new motif implementation ([04b717b](https://github.com/pinellolab/stormi/commit/04b717bb25caa69f04ebfbb22469c3faee5afb57))
* **preprocessing:** resolve test error and change variable names ([b05d756](https://github.com/pinellolab/stormi/commit/b05d7565b26b61cb8b5fa62ac3837800991045a7))
* **pyproject:** force torch to 3.12-compat version >=2.4 ([2d22ce0](https://github.com/pinellolab/stormi/commit/2d22ce01165bf1d38664aca60cf769bc0e455c20))
